% CHANGE TO REPLICATION FOLDER 
% cd "Replication"

use "The_Gallup_022318_EBRD.dta", clear 


sort WP5 YEAR_WAVE
save "ReplicationGWP.dta", replace
 
use "PolityPressFreedom.dta", clear 
rename country WP5
rename year YEAR_WAVE
sort WP5 YEAR_WAVE


merge 1:m WP5 YEAR_WAVE using "ReplicationGWP.dta"  



save "ReplicationGWP.dta", replace


set more off

drop if wpid == 7200100000297

*********************************************************
* GENERATE VARIABLES  *
*********************************************************

*** Top 10% of Income Distribution ***
gen wincome = wgt*INCOME_4
egen countyear = group(WP5 YEAR_WAVE)
egen mtop20wincome = mean(wincome) if INCOME_5 == 5, by(countyear)

gen top10 = 0
replace top10 = 1 if INCOME_5 == 5 & INCOME_4 >= mtop20wincome
replace top10 = . if missing(INCOME_4) | missing(INCOME_5)

replace INCOME_5 = 6 if top10 == 1

gen media_freedom_100 = 100 - score

*** Transform variables to dummy format ***

* happiness

replace WP16 = . if WP16 == 98 | WP16 ==99

replace WP137 = 0 if WP137 == 2
replace WP137 = . if WP137 == 3 | WP137 == 4

replace WP138 = 0 if WP138 == 2
replace WP138 = . if WP138 == 3 | WP138 == 4

replace WP139 = 0 if WP139 == 2
replace WP139 = . if WP139 == 3 | WP139 == 4

replace WP144 = 0 if WP144 == 2
replace WP144 = . if WP144 == 3 | WP144 == 4

replace WP145 = 0 if WP145 == 2
replace WP145 = . if WP145 == 3 | WP145 == 4

replace WP146 = 0 if WP146 == 2
replace WP146 = . if WP146 == 3 | WP146 == 4

replace WP150 = 0 if WP150 == 2
replace WP150 = . if WP150 == 3 | WP150 == 4

replace WP151 = 0 if WP151 == 2
replace WP151 = . if WP151 == 3 | WP151 == 4

replace WP152 = 0 if WP152 == 2
replace WP152 = . if WP152 == 3 | WP152 == 4

replace WP153 = 0 if WP153 == 2
replace WP153 = . if WP153 == 3 | WP153 == 4

replace WP157 = 0 if WP157 == 2
replace WP157 = . if WP157 == 3 | WP157 == 4

replace WP154 = 0 if WP154 == 2
replace WP154 = . if WP154 == 3 | WP154 == 4

replace WP159 = 0 if WP159 == 2
replace WP159 = . if WP159 == 3 | WP159 == 4

replace WP1423 = 0 if WP1423 == 2
replace WP1423 = . if WP1423 == 3 | WP1423 == 4

replace WP13125 = 0 if WP13125 == 2
replace WP13125 = . if WP13125 == 3 | WP13125 == 4

replace WP155 = 0 if WP155 == 2
replace WP155 = . if WP155 == 3 | WP155 == 4

replace WP156 = 0 if WP156 == 2
replace WP156 = . if WP156 == 3 | WP156 == 4

replace WP10251 = 0 if WP10251 == 2
replace WP10251 = . if WP10251 == 3 | WP10251 == 4

* perception of freedom of expression
replace WP1417 = . if WP1417 == 5 | WP1417 == 6
label var WP1417 "Perception of Freedom of Expression"

*** Types of occupations

gen prof = 0
replace prof = 1 if WP1225 == 1
replace prof = . if missing(WP1225)

gen manager = 0
replace manager = 1 if WP1225 == 2
replace manager = . if missing(WP1225)

gen busin = 0
replace busin = 1 if WP1225 == 3
replace busin = . if missing(WP1225)

gen office = 0
replace office = 1 if WP1225 == 4
replace office = . if missing(WP1225)

gen sales = 0
replace sales = 1 if WP1225 == 5
replace sales = . if missing(WP1225)

gen service = 0
replace service = 1 if WP1225 == 6
replace service = . if missing(WP1225)

gen constr = 0
replace constr = 1 if WP1225 == 7
replace constr = . if missing(WP1225)

gen manufac = 0
replace manufac = 1 if WP1225 == 8
replace manufac = . if missing(WP1225)

gen transport = 0
replace transport = 1 if WP1225 == 9
replace transport = . if missing(WP1225)

gen repair = 0
replace repair = 1 if WP1225 == 10
replace repair = . if missing(WP1225)


gen democracy = 2 if polity2 == 10
replace democracy = 1 if polity2 < 10 & polity2 > 5
replace democracy = 0 if polity2 < 6 & polity2 > -6
replace democracy = -1 if polity2 < -5


gen female = 0
replace female = 1 if WP1219 == 2
replace female = . if missing(WP1219)

gen age = WP1220/100 if WP1220 < 100
gen agesq = age*age

gen stown = 0
replace stown = 1 if WP14 == 2
replace stown = . if missing(WP14) | WP14 == 4 | WP14 == 5

gen suburb = 0
replace suburb = 1 if WP14 == 6
replace suburb = . if missing(WP14) | WP14 == 4 | WP14 == 5

gen lcity = 0
replace lcity = 1 if WP14 == 3
replace lcity = . if missing(WP14) | WP14 == 4 | WP14 == 5

replace WP155 = . if WP155 == 3 | WP155 == 4
replace WP155 = 0 if WP155 == 2
replace WP156 = . if WP156 == 3 | WP156 == 4
replace WP156 = 0 if WP156 == 2


gen second_educ = 0
replace second_educ = 1 if wp3117 == 2
replace second_educ = . if missing(wp3117) | wp3117 == 4 | wp3117 == 5

gen compl_educ = 0
replace compl_educ = 1 if wp3117 == 3
replace compl_educ = . if missing(wp3117) | wp3117 == 4 | wp3117 == 5

gen no_compl_educ = 1 - compl_educ

*** "Elite" variables and interaction terms

gen elite1 = 0
replace elite1 = 1 if INCOME_5 == 6
replace elite1 = . if missing(INCOME_5)

gen elite2 = compl_educ


gen freedom = 0
replace freedom = 1 if democracy == 2 | democracy == 1
replace freedom = . if missing(democracy)

gen freedom2 = 0
replace freedom2 = 1 if democracy == 2
replace freedom2 = . if missing(democracy)

gen top10_polity = polity2*elite1
gen top10_polity_10 = elite1*freedom2
gen top10_polity_5_10 = elite1*freedom



gen top10_free_press = elite1*free_press
gen frp = 0
replace frp = 1 if free_press == 2
replace frp = . if missing(free_press)
gen top10_fully_free_press = elite1*frp
gen top10_media100 = elite1*media_freedom_100/100


gen edu_polity = polity2*elite2
gen edu_polity_10 = elite2*freedom2
gen edu_polity_5_10 = elite2*freedom

gen edu_polity_9_10 = elite1
replace edu_polity_9_10 = 0 if polity2<9


gen edu_free_press = elite2*free_press
gen edu_fully_free_press = elite2*frp
gen edu_media100 = elite2*media_freedom_100/100

replace INCOME_4 = INCOME_4/1000000
gen LNINCOME_4 = ln(INCOME_4)

gen inc_polity = polity2*LNINCOME_4
gen inc_polity_10 = LNINCOME_4*freedom2
gen inc_polity_5_10 = LNINCOME_4*freedom
gen inc_free_press = LNINCOME_4*free_press
gen inc_fully_free_press = LNINCOME_4*frp
gen inc_media100 = LNINCOME_4*media_freedom_100/100

gen edu_censorship_100sq = elite2*(1-media_freedom_100/100)^2
gen edu_censorship_100 = elite2*(1-media_freedom_100/100)
 
label var edu_censorship_100 "Tertiary Education *  (1-Free Press Score/100)"
label var edu_censorship_100sq "Tertiary Education *  (1-Free Press Score/100)$^$2"


label var edu_polity "Tertiary Education * Polity2"
label var edu_polity_10 "Tertiary Education * Polity2=10"
label var edu_polity_5_10 "Tertiary Education * Polity2>5"
label var edu_polity_9_10 "Tertiary Education * Polity2>=9"



label var edu_fully_free_press "Tertiary Education * Fully Free Press"
label var edu_free_press "Tertiary Education * Free Press"
label var edu_media100 "Tertiary Education * Press Freedom Score/100"
label var top10_free_press "Top 10% Income * Free Press"
label var top10_fully_free_press "Top 10% Income * Fully Free Press"
label var top10_media100 "Top 10% Income * Press Freedom Score/100"
label var inc_free_press "Log Income * Free Press"
label var inc_fully_free_press "Log Income * Fully Free Press"
label var inc_media100 "Log Income * Press Freedom Score/100"

label var inc_polity "Log Income * Polity 2"

label var top10_polity "Top 10% Income * Polity 2"


label var WP150 "Approval of Country's Leadership"
label var compl_educ "Tertiary Education"
label var stown "Small Town"
label var suburb "Suburb of Large City"
label var lcity "Large City"
label var age "Age/100"
label var agesq "AgeSq/10000"
label var female "Female"
*"Log Income"
label var LNINCOME_4 "Log Income"
label var elite1 "Top 10% Income"

gen fp = 0
replace fp = 1 if free_press == 2 | free_press == 1
replace fp = . if missing(free_press)

gen fp_elite = (1-fp)*compl_educ
gen frp_elite = (1-frp)*compl_educ

label var frp_elite "Tertiary Education * (1 - Free Press)"
label var fp_elite "Tertiary Education * (1 - Partly Free or Free Press)"



set matsize 4000

xtset countyear



*********************************************************
* Table A6: PERCEPTIONS OF MEDIA FREEDOM, BY MEDIA FREEDOM, 5 BINS 
*********************************************************


eststo clear
xtreg WP10251 compl_educ stown suburb lcity age agesq female  if media_freedom_100<20, fe clu(countyear)
eststo
xtreg WP10251 compl_educ stown suburb lcity age agesq female  if media_freedom_100>=20&media_freedom_100<40, fe clu(countyear)
eststo
xtreg WP10251 compl_educ stown suburb lcity age agesq female  if media_freedom_100>=40&media_freedom_100<60, fe clu(countyear)
eststo
xtreg WP10251 compl_educ stown suburb lcity age agesq female  if media_freedom_100>=60&media_freedom_100<80, fe clu(countyear)
eststo
xtreg WP10251 compl_educ stown suburb lcity age agesq female  if media_freedom_100>=80, fe clu(countyear)
eststo

esttab using TableA6,  b(%4.3f) se(%4.3f)  ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  rtf  label replace ///
mtitles("0-19" "20-39" "40-59" "60-79" "80+"  ) ///
order(compl_educ female age agesq  stown suburb lcity ) 


*********************************************************
* Figure 6: PERCEPTIONS OF MEDIA FREEDOM, BY MEDIA FREEDOM, 5 BINS, NO INDIVIDUAL CONTROLS
*********************************************************

set more off

eststo clear
xtreg WP10251 compl_educ    if media_freedom_100<20, fe clu(countyear)
eststo
xtreg WP10251 compl_educ    if media_freedom_100>=20&media_freedom_100<40, fe clu(countyear)
eststo
xtreg WP10251 compl_educ    if media_freedom_100>=40&media_freedom_100<60, fe clu(countyear)
eststo
xtreg WP10251 compl_educ    if media_freedom_100>=60&media_freedom_100<80, fe clu(countyear)
eststo
xtreg WP10251 compl_educ    if media_freedom_100>=80, fe clu(countyear)
eststo

esttab using TableA6nocontrols,  b(%4.3f) se(%4.3f)  ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  rtf  label replace ///
mtitles("0-19" "20-39" "40-59" "60-79" "80+"  ) ///
order(compl_educ) 


*********************************************************
* Table A7: PERCEPTIONS OF MEDIA FREEDOM, INTERACTION TERMS
*********************************************************


set more off
eststo clear

xtreg WP10251 frp_elite stown suburb lcity age agesq female , fe clu(countyear)
eststo

xtreg WP10251 compl_educ frp_elite stown suburb lcity age agesq female , fe clu(countyear)
eststo

xtreg WP10251 fp_elite stown suburb lcity age agesq female , fe clu(countyear)
eststo
xtreg WP10251 compl_educ fp_elite stown suburb lcity age agesq female , fe clu(countyear)
eststo


xtreg WP10251   edu_censorship_100 stown suburb lcity age agesq female , fe clu(countyear)
eststo
xtreg WP10251 compl_educ edu_censorship_100 stown suburb lcity age agesq female , fe clu(countyear)

eststo

xtreg WP10251  edu_censorship_100sq stown suburb lcity age agesq female , fe clu(countyear)
eststo

xtreg WP10251 compl_educ edu_censorship_100sq stown suburb lcity age agesq female , fe clu(countyear)
eststo

esttab using TableA7,  b(%4.3f) se(%4.3f)  ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  rtf  label replace ///
order(fp_elite frp_elite edu_censorship_100 edu_censorship_100sq compl_educ female age agesq stown suburb lcity  )


*********************************************************
* Table A8: TABLE APPROVAL, SUBSAMPLES 
*********************************************************

set more off

eststo clear
xtreg WP150 compl_educ stown suburb lcity age agesq female  if polity2 <-5, fe clu(countyear)
eststo
xtreg WP150 compl_educ stown suburb lcity age agesq female  if polity2 >= -5 & polity2 <=0, fe clu(countyear)
eststo
xtreg WP150 compl_educ stown suburb lcity age agesq female  if polity2>0& polity2 <=5, fe clu(countyear)
eststo
xtreg WP150 compl_educ stown suburb lcity age agesq female  if polity2==6, fe clu(countyear)
eststo
xtreg WP150 compl_educ stown suburb lcity age agesq female  if polity2==7, fe clu(countyear)
eststo
xtreg WP150 compl_educ stown suburb lcity age agesq female  if polity2==8, fe clu(countyear)
eststo
xtreg WP150 compl_educ stown suburb lcity age agesq female  if polity2 ==9, fe clu(countyear)
eststo
xtreg WP150 compl_educ stown suburb lcity age agesq female  if polity2 ==10, fe clu(countyear)
eststo

esttab using TableA8,  b(%4.3f) se(%4.3f)  ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  rtf  label replace ///
mtitles("Polity2<-5"  "-5<=Polity2<=0" "0<Polity2<=5" "Polity2=6" "Polity2=7" "Polity2=8" "Polity2=9" "Polity2=10"     ) ///
order(compl_educ female age agesq  stown suburb lcity ) 


*********************************************************
* FIGURE 7: TABLE APPROVAL, SUBSAMPLES, NO INDIVIDUAL CONTROLS
*********************************************************

set more off

eststo clear
xtreg WP150 compl_educ    if polity2 <-5, fe clu(countyear)
eststo
xtreg WP150 compl_educ    if polity2 >= -5 & polity2 <=0, fe clu(countyear)
eststo
xtreg WP150 compl_educ    if polity2>0& polity2 <=5, fe clu(countyear)
eststo
xtreg WP150 compl_educ    if polity2==6, fe clu(countyear)
eststo
xtreg WP150 compl_educ    if polity2==7, fe clu(countyear)
eststo
xtreg WP150 compl_educ    if polity2==8, fe clu(countyear)
eststo
xtreg WP150 compl_educ    if polity2 ==9, fe clu(countyear)
eststo
xtreg WP150 compl_educ    if polity2 ==10, fe clu(countyear)
eststo

esttab using TableA8nocontrols,  b(%4.3f) se(%4.3f)  ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  rtf  label replace ///
mtitles("Polity2<-5"  "-5<=Polity2<=0" "0<Polity2<=5" "Polity2=6" "Polity2=7" "Polity2=8" "Polity2=9" "Polity2=10"     ) ///
order(compl_educ ) 



*********************************************************
* Table A9: APPROVAL WITH INTERACTIONS EDUCATION WITH CONTINUOUS POLITY2 AND MEDIA FREEDOM
*********************************************************

set more off
eststo clear
 
xtreg WP150 compl_educ edu_polity stown suburb lcity age agesq female , fe clu(countyear)
eststo
xtreg WP150 compl_educ edu_polity_10 stown suburb lcity age agesq female , fe clu(countyear)
eststo
xtreg WP150 compl_educ edu_polity_5_10 stown suburb lcity age agesq female , fe clu(countyear)
eststo
xtreg WP150 compl_educ edu_fully_free_press stown suburb lcity age agesq female , fe clu(countyear)
eststo
xtreg WP150 compl_educ edu_free_press stown suburb lcity age agesq female , fe clu(countyear)
eststo
xtreg WP150 compl_educ edu_media100 stown suburb lcity age agesq female , fe clu(countyear)
eststo

esttab using TableA9, compress b(%4.3f) se(%4.3f)  ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  rtf  label replace order(compl_educ edu_polity edu_polity_10  edu_polity_5_10 edu_fully_free_press edu_free_press edu_media100 female age agesq  stown suburb lcity )


*********************************************************
* Table A10: MINCER EQUATION *
*********************************************************


replace INCOME_4 = INCOME_4*10

label var elite2 "Tertiary Education"
label var second_educ "Secondary Education"

label var elite1 "Top 10% Income"
label var LNINCOME_4 "Log Income"


label var prof "Professional Worker"
label var manager "Manager or Official"
label var busin "Business Owner"
label var office "Clerical or Office Worker"
label var sales "Sales Worker"
label var service "Service Worker"
label var constr "Construction or Mining Worker"
label var manufac "Manufacturing Worker"
label var transport "Transportation Worker"
label var repair "Installation or Repair Worker"

eststo clear
xtreg LNINCOME_4 elite2 second_educ stown suburb lcity age agesq female , fe clu(countyear)
eststo
xtreg LNINCOME_4 elite2 second_educ stown suburb lcity age agesq female prof manager busin office sales service constr manufac transport repair  if WP1225 < 12, fe clu(countyear)
eststo
xtreg   elite1 elite2 second_educ stown suburb lcity age agesq female , fe clu(countyear)
eststo
xtreg   elite1 elite2 second_educ stown suburb lcity age agesq female prof manager busin office sales service constr manufac transport repair  if WP1225 < 12, fe clu(countyear)
eststo

esttab using TableMincer,  b(%4.3f) se(%4.3f)  ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  tex  label replace depvars  ///
order(elite2 second_educ female age agesq stown suburb lcity  )

esttab using TableA10,  b(%4.3f) se(%4.3f)  ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  rtf  label replace depvars  ///
order(elite2 second_educ female age agesq stown suburb lcity  )

*** Table A11: MINCER EQUATION by subsamples

set more off 
eststo clear
xtreg LNINCOME_4 elite2 second_educ stown suburb lcity age agesq female if polity2 <-5, fe clu(countyear)
eststo
xtreg LNINCOME_4 elite2 second_educ stown suburb lcity age agesq female if polity2 >=-5&polity2 <=0, fe clu(countyear)
eststo
xtreg LNINCOME_4 elite2 second_educ stown suburb lcity age agesq female if polity2 >0&polity2 <=5, fe clu(countyear)
eststo
xtreg LNINCOME_4 elite2 second_educ stown suburb lcity age agesq female if polity2 >=6&polity2 <=8, fe clu(countyear)
eststo
xtreg LNINCOME_4 elite2 second_educ stown suburb lcity age agesq female if polity2 ==9, fe clu(countyear)
eststo
xtreg LNINCOME_4 elite2 second_educ stown suburb lcity age agesq female if polity2 ==10, fe clu(countyear)
eststo

esttab using TableA11,  b(%4.3f) se(%4.3f)  ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  rtf  label replace   ///
mtitles( "Polity2<-5"  "-5<=Polity2<=0" "0<Polity2<=5"  "6<=Polity2<=8"  "Polity2=9" "Polity2=10"   ) ///
order(elite2 second_educ female age agesq stown suburb lcity  )



*********************************************************
* Table A12: LIFE SATISFACTION AS A FUNCTION OF EDUCATION, SUBSAMPLES 
*********************************************************

set more off

eststo clear
xtreg WP16 compl_educ stown suburb lcity age agesq female  if polity2 <-5, fe clu(countyear)
eststo
xtreg WP16 compl_educ stown suburb lcity age agesq female  if polity2 >= -5 & polity2 <=0, fe clu(countyear)
eststo
xtreg WP16 compl_educ stown suburb lcity age agesq female  if polity2>0& polity2 <=5, fe clu(countyear)
eststo
xtreg WP16 compl_educ stown suburb lcity age agesq female  if polity2 >=6 & polity2 <=8, fe clu(countyear)
eststo
xtreg WP16 compl_educ stown suburb lcity age agesq female  if polity2 ==9, fe clu(countyear)
eststo
xtreg WP16 compl_educ stown suburb lcity age agesq female  if polity2 ==10, fe clu(countyear)
eststo

esttab using TableA12,  b(%4.3f) se(%4.3f)  ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  rtf  label replace ///
mtitles( "Polity2<-5"  "-5<=Polity2<=0" "0<Polity2<=5"  "6<=Polity2<=8"  "Polity2=9" "Polity2=10"   ) ///
order(compl_educ female age agesq  stown suburb lcity ) 



*********************************************************
* Table A13: APPROVAL AS A FUNCTION OF EDUCATION CONTROLLING FOR INCOME
*********************************************************


set more off 
eststo clear
xtreg WP150 compl_educ LNINCOME_4 stown suburb lcity age agesq female  if polity2 <-5, fe clu(countyear)
eststo
xtreg WP150 compl_educ LNINCOME_4 stown suburb lcity age agesq female  if polity2 >=-5&polity2 <=0, fe clu(countyear)
eststo
xtreg WP150 compl_educ LNINCOME_4 stown suburb lcity age agesq female  if polity2 >0&polity2 <=5, fe clu(countyear)
eststo
xtreg WP150 compl_educ LNINCOME_4 stown suburb lcity age agesq female  if polity2 >=6&polity2 <=8, fe clu(countyear)
eststo
xtreg WP150 compl_educ LNINCOME_4 stown suburb lcity age agesq female  if polity2 ==9, fe clu(countyear)
eststo
xtreg WP150 compl_educ LNINCOME_4 stown suburb lcity age agesq female  if polity2 ==10, fe clu(countyear)
eststo

esttab using TableA13,  b(%4.3f) se(%4.3f)  ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  rtf  label replace ///
mtitles( "Polity2<-5"  "-5<=Polity2<=0" "0<Polity2<=5"  "6<=Polity2<=8"  "Polity2=9" "Polity2=10"   ) ///
order(compl_educ LNINCOME_4 female age agesq  stown suburb lcity ) 




